# Copyright © 2023 ValidMind Inc. All rights reserved.

"""
Entrypoint for classification datasets.
"""
import pandas as pd

__all__ = [
    "customer_churn",
    "taiwan_credit",
]


def simple_preprocess_booleans(df, columns):
    """
    Preprocess boolean columns.

    Args:
        df (pandas.DataFrame): Dataframe to preprocess.
        columns (list): List of columns to preprocess.

    Returns:
        pandas.DataFrame: Preprocessed dataframe.
    """
    df = df.copy()

    for col in columns:
        unique_values = df[col].unique()
        # Create a dictionary mapping the unique values to integers
        mapping = dict(zip(unique_values, range(len(unique_values))))
        # Map the values to integers using the mapping
        df[col] = df[col].map(mapping)

    return df


def simple_preprocess_categoricals(df, columns):
    """
    Preprocess categorical columns.

    Args:
        df (pandas.DataFrame): Dataframe to preprocess.
        columns (list): List of columns to preprocess.

    Returns:
        pandas.DataFrame: Preprocessed dataframe.
    """
    df = df.copy()

    for col in columns:
        df = pd.concat([df, pd.get_dummies(df[col], prefix=col)], axis=1)
        df.drop(col, axis=1, inplace=True)

    return df


def simple_preprocess_numericals(df, columns):
    """
    Preprocess numerical columns.

    Args:
        df (pandas.DataFrame): Dataframe to preprocess.
        columns (list): List of columns to preprocess.

    Returns:
        pandas.DataFrame: Preprocessed dataframe.
    """
    df = df.copy()

    for col in columns:
        df[col] = df[col].fillna(df[col].mean())

    return df
